@@ -139,9 +139,9 @@ module NumRu
       t = dx[1..-1]                                 # x_{i+1} - x_{i} (for i=0..n-3)
       s2 = dx2[0..-2].reshape(*to_rankD)            # s**2
       t2 = dx2[1..-1].reshape(*to_rankD)            # t**2
-      numerator =     s2      * ze[ *([true]*dim+[2..-1,false]) ] \
-                    + (t2-s2) * ze[ *([true]*dim+[1..-2,false]) ] \
-                    - t2      * ze[ *([true]*dim+[0..-3,false]) ]
+      numerator =     ze[ *([true]*dim+[2..-1,false]) ] *  s2\
+                    + ze[ *([true]*dim+[1..-2,false]) ] * (t2-s2) \
+                    - ze[ *([true]*dim+[0..-3,false]) ] *  t2
       denominator = (s*t*(s+t)).reshape(*to_rankD)
       dzdx = numerator / denominator
       return dzdx
